Recognition class

Constructors

Recognition({String name = '', List<double> embedding = const [], double distance = 0.0})

Properties

distance double
final
embedding List<double>
final
hashCode int
The hash code for this object.
no setteroverride
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, List<double>? embedding, double? distance}) Recognition
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(covariant Recognition other) bool
The equality operator.
override